@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid = "$Id: set.c,v 1.68 1998/06/22 12:24:54 ddenholm Exp $";
+static char *RCSid = "$Id: set.c,v 1.21.2.1 1999/08/19 14:36:35 lhecking Exp $";
 #endif
 
 /* GNUPLOT - set.c */
@@ -661,6 +661,12 @@ else if (almost_equals(c_token, MAX)) { AUTO |= 2;    ++c_token; }
 	} else if (equals(c_token, "y")) {
 	    autoscale_y = FALSE;
 	    c_token++;
+	} else if (equals(c_token, "x2")) {
+	    autoscale_x2 = FALSE;
+	    c_token++;
+	} else if (equals(c_token, "y2")) {
+	      autoscale_y2 = FALSE;
+	      c_token++;
 	} else if (equals(c_token, "z")) {
 	    autoscale_z = FALSE;
 	    c_token++;
